@@ -1,3 +1,4 @@
+import os
 from typing import Optional
 
 import typer
@@ -27,7 +28,18 @@ def setup(
         None, prompt="Please input your CircleCI token"
     ),
 ):
-    utils.save_config({"vcs": vcs, "organization": org, "circle_token": token})
+    configuration = utils.save_config(
+        {"vcs": vcs, "organization": org, "circle_token": token}
+    )
+
+    filename = os.path.basename(configuration.user_config_path())
+    utils.exit_cli(message=f"Configuration File created at {filename}", status_code=0)
+
+
+@config_app.command(help="Display the path to the current configuration file")
+def locate():
+    configuration = utils.read_config()
+    typer.echo(configuration.user_config_path())
 
 
 @config_app.command(help="Display the current configuration")
