@@ -1,5 +1,4 @@
 from enum import Enum
-import os
 import sys
 from typing import Dict
 
@@ -14,22 +13,19 @@ class OutputFormat(Enum):
     json = "json"
 
 
-def save_config(config_values: Dict) -> None:
+def save_config(config_values: Dict) -> confuse.Configuration:
     config = read_config()
-    config_dir = config.config_dir()
-    config_filename = confuse.CONFIG_FILENAME
 
     if config.exists():
         config.clear()
 
     config.add(config_values)
-    config_full_path = os.path.join(config_dir, config_filename)
-    with open(config_full_path, "w") as file:
+    with open(config.user_config_path(), "w") as file:
         file.seek(0)
         file.write(config.dump())
         file.truncate()
 
-    exit_cli(message=f"Configuration File created at {config_filename}", status_code=0)
+    return config
 
 
 def read_config() -> confuse.Configuration:
@@ -38,10 +34,10 @@ def read_config() -> confuse.Configuration:
 
 def exit_cli(message: str, status_code: int) -> None:
     status_symbol = "✅" if status_code == 0 else "❌"
-    typer.echo(f"{status_symbol}  {message}")
+    typer.echo(f"{status_symbol}  {message}", err=True)
     sys.exit(status_code)
 
 
 def show_progress():
-    sys.stdout.write(".")
-    sys.stdout.flush()
+    sys.stderr.write(".")
+    sys.stderr.flush()
